==> datavan-4.2.1.tgz: package/lib/es6/cache-util.js <==
import _mapValues from "lodash/mapValues";
import _keys from "lodash/keys";
import _pick from "lodash/pick";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import shallowEqual from 'fbjs/lib/shallowEqual';
export var createBatchMemoizer = function createBatchMemoizer(onSuccess) {
  var batchIndex = 0;
  var lastColls = {};
  var lastProps = {};
  var results = {};
  var promises = {};

  function memoize(inlineFunc, props) {
    var batchI = batchIndex;
    batchIndex++;
    var db = this;
    var lastColl = lastColls[batchI];
    var collEqual = shallowEqual(lastColl, _pick(db, _keys(lastColl))); // eslint-disable-next-line

    var propsEqual = lastProps.hasOwnProperty(batchI) && shallowEqual(lastProps[batchI], props);
    if (collEqual && propsEqual) return results[batchI];
    lastProps[batchI] = props;
    var touchNames = {};

    var useDb = _objectSpread({}, db, ['recall', 'getById', 'getSubmits', 'getOriginals', 'getFetchData'].reduce(function (newDb, funcName) {
      newDb[funcName] = function () {
        for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
          args[_key2] = arguments[_key2];
        }

        // record touched name
        touchNames[args[0]] = true;
        return db[funcName].apply(db, args);
      };

      return newDb;
    }, {}));

    for (var _len = arguments.length, restArgs = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
      restArgs[_key - 2] = arguments[_key];
    }

    var promise = inlineFunc.apply(void 0, [useDb, props].concat(restArgs)); // console.log('>touchNames>>', touchNames)

    lastColls[batchI] = _mapValues(touchNames, function (v, name) {
      return db[name];
    });
    var ret;

    if (promise && promise.then) {
      promise.then(function (result) {
        results[batchI] = result;
        delete promises[batchI];
        return onSuccess(result, batchI);
      }, function (error) {
        delete promises[batchI];
        return Promise.reject(error);
      });
      promises[batchI] = promise;
    } else {
      ret = promise;
    }

    return results[batchI] = ret; // eslint-disable-line
  }

  return {
    results: results,
    promises: promises,
    newBatch: function newBatch(db) {
      batchIndex = 0;
      return _objectSpread({}, db, {
        memoize: memoize
      });
    }
  };
}; // const createAsyncCache = ({ handler, onSuccess, onError } = {}) => {
//   const results = {}
//   const promises = {}
//   const cache = (key, inlineFunc) => {
//     if (typeof key !== 'string') key = stringify(key)
//     if (key in results) return results[key]
//
//     const promise = (inlineFunc || handler)(key)
//     let ret
//     if (promise && promise.then) {
//       promise.then(
//         result => {
//           results[key] = result
//           delete promises[key]
//           return onSuccess(result, key)
//         },
//         error => {
//           promises[key] = error
//           return onError(error, key)
//         }
//       )
//       promises[key] = promise
//     } else {
//       ret = promise
//     }
//     return (results[key] = ret) // eslint-disable-line
//   }
//   cache.results = results
//   cache.promises = promises
//   return cache
// }

==> datavan-4.2.4.tgz: package/lib/es6/cache-util.js <==
import _mapValues from "lodash/mapValues";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import shallowEqual from 'fbjs/lib/shallowEqual';
var touchCollectionFuncs = ['getLocalData', 'getFetchData'];
export var createBatchMemoizer = function createBatchMemoizer(onSuccess) {
  var batchIndex = 0;
  var lastColls = {};
  var lastProps = {};
  var results = {};
  var promises = {};

  function memoize(inlineFunc, props) {
    var batchI = batchIndex;
    batchIndex++;
    var db = this;
    var lastColl = lastColls[batchI];

    var currColl = _mapValues(lastColl, function (oldColl, name) {
      return db.getLocalData(name);
    });

    var collEqual = shallowEqual(lastColl, currColl); // eslint-disable-next-line

    var propsEqual = lastProps.hasOwnProperty(batchI) && shallowEqual(lastProps[batchI], props);
    if (collEqual && propsEqual) return results[batchI];
    lastProps[batchI] = props;
    var touchNames = {}; // db-with-memoize

    var dbWithWrappedFuncs = _objectSpread({}, db, touchCollectionFuncs.reduce(function (newDb, funcName) {
      newDb[funcName] = function () {
        for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
          args[_key2] = arguments[_key2];
        }

        // record touched name
        touchNames[args[0]] = true;
        return db[funcName].apply(db, args);
      };

      return newDb;
    }, {}));

    for (var _len = arguments.length, restArgs = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
      restArgs[_key - 2] = arguments[_key];
    }

    var promise = inlineFunc.apply(void 0, [dbWithWrappedFuncs, props].concat(restArgs)); // console.log('>touchNames>>', touchNames)

    lastColls[batchI] = _mapValues(touchNames, function (v, name) {
      return db.getLocalData(name);
    });
    var ret;

    if (promise && promise.then) {
      promise.then(function (result) {
        results[batchI] = result;
        delete promises[batchI];
        return onSuccess(result, batchI);
      }, function (error) {
        delete promises[batchI];
        return Promise.reject(error);
      });
      promises[batchI] = promise;
    } else {
      ret = promise;
    }

    return results[batchI] = ret; // eslint-disable-line
  }

  return {
    results: results,
    promises: promises,
    newBatch: function newBatch(db) {
      batchIndex = 0; // make a db-with-memoize

      return _objectSpread({}, db, {
        memoize: memoize
      });
    }
  };
}; // const createAsyncCache = ({ handler, onSuccess, onError } = {}) => {
//   const results = {}
//   const promises = {}
//   const cache = (key, inlineFunc) => {
//     if (typeof key !== 'string') key = stringify(key)
//     if (key in results) return results[key]
//
//     const promise = (inlineFunc || handler)(key)
//     let ret
//     if (promise && promise.then) {
//       promise.then(
//         result => {
//           results[key] = result
//           delete promises[key]
//           return onSuccess(result, key)
//         },
//         error => {
//           promises[key] = error
//           return onError(error, key)
//         }
//       )
//       promises[key] = promise
//     } else {
//       ret = promise
//     }
//     return (results[key] = ret) // eslint-disable-line
//   }
//   cache.results = results
//   cache.promises = promises
//   return cache
// }
